
/*====================================================================*/
/*  Name:     DES_EXT.H                                               */
/*====================================================================*/
/*                                                                    */
/*  (C) COPYRIGHT International Business Machines Corp. 1987, 1995    */
/*  All Rights Reserved                                               */
/*  Licensed Materials - Property of IBM                              */
/*                                                                    */
/*  US Government Users Restricted Rights - Use, duplication or       */
/*  disclosure restricted by GSA ADP Schedule Contract with IBM Corp. */
/*                                                                    */
/*  Function = Include File defining:                                 */
/*             System Constants                                       */
/*             Function Prototypes                                    */
/*                                                                    */
/*  Operating System: AIX, OS/2, Windows NT, Windows 3.1              */
/*                                                                    */
/*====================================================================*/

#ifndef  DES_H_EXT
#define  DES_H_EXT

#ifndef  SQL_H_SQLCLI1
#include <sqlcli1.h>
#endif

/*--------------------------------------------------------------------*/
/*  Return Code values                                                */
/*--------------------------------------------------------------------*/
#define  RC_SUCCESS                              0
#define  RC_ERROR                              101
#define  RC_INVALID_PARAMETER                  102
#define  RC_PARSER_SYNTAX_ERROR                103
#define  RC_INTERNAL_ERROR                     104
#define  RC_INVALID_TABLE                      105
#define  RC_INVALID_COLUMN                     106
#define  RC_INVALID_SEARCH_OPTION              107
#define  RC_INVALID_BROWSE_OPTION              108
#define  RC_FILE_IO_PROBLEM                    110
#define  RC_TEXT_COLUMN_NOT_ENABLED            111
#define  RC_NO_BROWSE_INFO                     112
#define  RC_PARSER_INVALID_ESCAPE_CHARACTER    113
#define  RC_PARSER_INVALID_USE_OF_ESCAPE_CHAR  114
#define  RC_SE_NO_DATA                         115
#define  RC_INVALID_MATCH_OPTION               116
#define  RC_INVALID_DES_VERSION                118
#define  RC_PARSER_DEFAULT_INVALID_LANGUAGE    119
#define  RC_INVALID_SESSION                    120
#define  RC_ALLOCATION_ERROR                   121
#define  RC_INVALID_BROWSE_INFO                122
#define  RC_RESULT_TABLE_NOT_EXIST             123

#define  RC_LANGUAGE_NOT_SUPPORTED_FOR_INDEX   161
#define  RC_FEATURE_EXTRACTION_NOT_ENABLED     162
#define  RC_THESAURUS_NOT_SUPPORTED            163
#define  RC_SOUNDS_LIKE_NOT_SUPPORTED          164
#define  RC_SYNONYM_NOT_SUPPORTED              165
#define  RC_IS_ABOUT_NOT_SUPPORTED             166
#define  RC_BOUND_NOT_SUPPORTED                167
#define  RC_STEMMED_FORM_NOT_SUPPORTED         168
#define  RC_PRECISE_FORM_NOT_SUPPORTED         169
#define  RC_FUZZY_FORM_NOT_SUPPORTED           170

/*--------------------------------------------------------------------*/
/*  Return Code values resulting from DB2 errors                      */
/*--------------------------------------------------------------------*/
                                       /* SQL error occurred, no more */
                                       /* information available       */
#define  RC_SQL_ERROR_NO_INFO                  201
                                       /* SQL error occurred,         */
                                       /* (only) original SQL error   */
                                       /* information available       */
#define  RC_SQL_ERROR_WITH_INFO                202
                                       /* SQL error occurred          */
                                       /* while freeing connection    */
#define  RC_SQL_FREE_ERROR                     203

/*--------------------------------------------------------------------*/
/*  Return Code values resulting from Text Engine errors              */
/*--------------------------------------------------------------------*/
#define  RC_SE_END_OF_INFORMATION              302
#define  RC_SE_EMPTY_LIST                      303
#define  RC_SE_PROCESSING_LIMIT_EXCEEDED       312
#define  RC_SE_UNKNOWN_SERVER_NAME             316
#define  RC_SE_QUERY_TOO_COMPLEX               322
#define  RC_SE_UNKNOWN_INDEX_NAME              324
#define  RC_SE_INCORRECT_HANDLE                325
#define  RC_SE_UNEXPECTED_ERROR                332
#define  RC_SE_SERVER_NOT_AVAILABLE            333
#define  RC_SE_SERVER_BUSY                     347
#define  RC_SE_SERVER_CONNECTION_LOST          348
#define  RC_SE_REQUEST_IN_PROGRESS             350
#define  RC_SE_INDEX_DELETED                   360
#define  RC_SE_INDEX_SUSPENDED                 361
#define  RC_SE_INDEX_NOT_ACCESSIBLE            362
#define  RC_SE_MAX_NUMBER_OF_BUSY_INDEXES      363
#define  RC_SE_NOT_ENOUGH_MEMORY               365
#define  RC_SE_MAX_OUTPUT_SIZE_EXCEEDED        368
#define  RC_SE_BROWSER_TIME_OUT                369
#define  RC_SE_COMMUNICATION_PROBLEM           370
#define  RC_SE_EMPTY_INDEX                     372
#define  RC_SE_EMPTY_QUERY                     373
#define  RC_SE_INSTALLATION_PROBLEM            374
#define  RC_SE_FUNCTION_DISABLED               375
#define  RC_SE_FUNCTION_IN_ERROR               376
#define  RC_SE_IO_PROBLEM                      377
#define  RC_SE_WRITE_TO_DISK_ERROR             378
#define  RC_SE_LINGUISTIC_SERVICE_FAILED       385
#define  RC_SE_LS_NOT_EXECUTABLE               397
#define  RC_SE_LS_FUNCTION_FAILED              398
#define  RC_SE_CAPACITY_LIMIT_EXCEEDED         399
#define  RC_SE_DOCUMENT_NOT_ACCESSIBLE         400
#define  RC_SE_DOCUMENT_NOT_FOUND              403

#define  RC_SE_UNKNOWN_ERROR                   479

/*--------------------------------------------------------------------*/
/*  Return Code values resulting from Text Engine warnings            */
/*--------------------------------------------------------------------*/
#define  RC_SE_DICTIONARY_NOT_FOUND            481
#define  RC_SE_STOPWORD_IGNORED                482
#define  RC_SE_CONFLICT_WITH_INDEX_TYPE        483

/*--------------------------------------------------------------------*/
/*  Item Types                                                        */
/*--------------------------------------------------------------------*/
#define  DB2TX_START         0xE2      /* start item                  */
#define  DB2TX_END           0xC5      /* end item                    */
#define  DB2TX_ATOMIC        0xC1      /* atomic item                 */

/*--------------------------------------------------------------------*/
/*  Item Identifiers                                                  */
/*--------------------------------------------------------------------*/
#define  DB2TX_SNAM            80      /* -- section name             */
#define  DB2TX_CCSID          115      /* -- coded character set id.  */
#define  DB2TX_LANG           116      /* -- language identifier      */
#define  DB2TX_DOC            410      /* -- document delimiter       */
#define  DB2TX_DNAM           415      /* -- document name            */
#define  DB2TX_DEL            420      /* -- doc element delimiter    */
#define  DB2TX_PAR            430      /* -- paragraph delimiter      */
#define  DB2TX_TEXT           440      /* -- text portion             */
#define  DB2TX_NL             444      /* -- new line indicator       */
#define  DB2TX_LINK           446      /* -- hypermedia reference     */
#define  DB2TX_MATCH          450      /* -- match information        */

/*--------------------------------------------------------------------*/
/*  Coded Character Set Identifiers  (CCSID)                          */
/*--------------------------------------------------------------------*/
/*  SAA CCSIDs for Latin-1 countries (character set 697):             */
#define  DB2TX_CCSID_00037     37      /* CECP: USA, CND, and others  */
#define  DB2TX_CCSID_00273    273      /* CECP: Austria, Germany      */
#define  DB2TX_CCSID_00277    277      /* CECP: Denmark, Norway       */
#define  DB2TX_CCSID_00278    278      /* CECP: Finland, Sweden       */
#define  DB2TX_CCSID_00280    280      /* CECP: Italy                 */
#define  DB2TX_CCSID_00284    284      /* CECP: Spain, Latin America  */
#define  DB2TX_CCSID_00285    285      /* CECP: United Kingdom        */
#define  DB2TX_CCSID_00297    297      /* CECP: France                */
#define  DB2TX_CCSID_00500    500      /* CECP: International Latin-1 */
#define  DB2TX_CCSID_00819    819      /* ISO 8859-1:  Latin-1        */
#define  DB2TX_CCSID_00871    871      /* CECP: Iceland               */
#define  DB2TX_CCSID_04946   4946      /* PC Data-190: Latin-1 =CP850 */
/*--------------------------------------------------------------------*/
/*  SAA CCSID  for Japanese:                                          */
#define  DB2TX_CCSID_00932    932      /* Combined Japanese SBCS/DBCS */
#define  DB2TX_CCSID_00942    942      /* Combined Japanese SBCS/DBCS */
#define  DB2TX_CCSID_00943    943      /* Combined Japanese SBCS/DBCS */
#define  DB2TX_CCSID_00954    954      /* Japanese EUC                */
#define  DB2TX_CCSID_05039   5039      /* Combined Japanese SBCS/DBCS */
/*--------------------------------------------------------------------*/
/*  SAA CCSID  for Traditional Chinese:                               */
#define  DB2TX_CCSID_00948    948      /* Combined Trad. C. SBCS/DBCS */
#define  DB2TX_CCSID_00950    950      /* Combined Trad. C. SBCS/DBCS */
#define  DB2TX_CCSID_00964    964      /* Traditional Chinise EUC     */
/*--------------------------------------------------------------------*/
/*  SAA CCSID  for Simplified Chinese:                                */
#define  DB2TX_CCSID_01381   1381      /* Combined Simpl.C. SBCS/DBCS */
#define  DB2TX_CCSID_01383   1383      /* Combined Simpl.C. SBCS/DBCS */
#define  DB2TX_CCSID_01386   1386      /* Simple Chinese PC Data      */
/*--------------------------------------------------------------------*/
/*  SAA CCSID  for Korean:                                            */
#define  DB2TX_CCSID_00949    949      /* Combined Korean   SBCS/DBCS */
#define  DB2TX_CCSID_00970    970      /* Combined Korean   SBCS/DBCS */
#define  DB2TX_CCSID_01363   1363      /* Combined Korean   SBCS/DBCS */
/*--------------------------------------------------------------------*/
/*  selected Migration/Coexistence CCSIDs for Latin-1 countries:      */
#define  DB2TX_CCSID_00437    437      /* PC Data-222; PC Base: USA ..*/
#define  DB2TX_CCSID_00850    850      /* PC Data; MLP 222: Latin-1   */
#define  DB2TX_CCSID_00860    860      /* PC Data: Portugal           */
#define  DB2TX_CCSID_00861    861      /* PC Data: Iceland            */
#define  DB2TX_CCSID_00863    863      /* PC Data: Canada             */
#define  DB2TX_CCSID_00865    865      /* PC Data: Denmark, Norway    */

/*--------------------------------------------------------------------*/
/*  CCSIDs for Cyrillic (Russian):                                    */
#define  DB2TX_CCSID_00866    866      /* PC Data: Cyrillic           */
#define  DB2TX_CCSID_00878    878      /* Cyrillic Internet           */
#define  DB2TX_CCSID_00915    915      /* AIX Data: Cyrillic          */
#define  DB2TX_CCSID_01025   1025      /* EBCDIC Cyrillic             */
#define  DB2TX_CCSID_01251   1251      /* Windows Cyrillic            */
         
/*--------------------------------------------------------------------*/
/*  Language Identifiers                                              */
/*--------------------------------------------------------------------*/
#define  DB2TX_LANG_CAT      3820      /* Catalan                     */
#define  DB2TX_LANG_CHS      4029      /* Simplified Chinese          */
#define  DB2TX_LANG_CHT      4030      /* Traditional Chinese         */
#define  DB2TX_LANG_DAN      4714      /* Danish                      */
#define  DB2TX_LANG_DEU      4841      /* German                      */
#define  DB2TX_LANG_DES      4839      /* Swiss German                */
#define  DB2TX_LANG_ENG      5997      /* UK English                  */
#define  DB2TX_LANG_ENU      6011      /* US English                  */
#define  DB2TX_LANG_ESP      6156      /* Spanish                     */
#define  DB2TX_LANG_FIN      6754      /* Finnish                     */
#define  DB2TX_LANG_FRA      7011      /* French                      */
#define  DB2TX_LANG_FRC      7013      /* Canadian French             */
#define  DB2TX_LANG_ISL      9752      /* Icelandic                   */
#define  DB2TX_LANG_ITA      9771      /* Italian                     */
#define  DB2TX_LANG_JAP     10564      /* Japanese                    */
#define  DB2TX_LANG_KOR     11438      /* Korean                      */
#define  DB2TX_LANG_NLD     14034      /* Dutch                       */
#define  DB2TX_LANG_NOB     14122      /* Norwegian - Bokmal          */
#define  DB2TX_LANG_NON     14134      /* Norwegian - Nynorsk         */
#define  DB2TX_LANG_NOR     14138      /* Norwegian - both            */
#define  DB2TX_LANG_PTG     16077      /* Portuguese                  */
#define  DB2TX_LANG_PTB     16072      /* Brazilian Portuguese        */
#define  DB2TX_LANG_RUS     17919      /* Russian                     */
#define  DB2TX_LANG_SVE     18835      /* Swedish                     */

/*--------------------------------------------------------------------*/
/*  Limits                                                            */
/*--------------------------------------------------------------------*/
                                       /* maximum API message length  */
#define  DES_MAX_MESSAGE_LENGTH        1024

#ifndef  DES_COMMON_DEFS
#define  DES_COMMON_DEFS
                                       /* maximum text handle length  */
#define  DES_MAX_TEXT_HANDLE_LENGTH     200

/*--------------------------------------------------------------------*/
/*  Type Definitions                                                  */
/*--------------------------------------------------------------------*/
typedef  long int            DESRETURN;
typedef  unsigned long       DESULONG;
typedef  unsigned short      DESUSHORT;
typedef  short int           DESSMALLINT;
typedef  unsigned char       DESCHAR;

#endif
                                       /* search option               */
typedef  unsigned long       DESSEARCHOPTION;
                                       /* browse option               */
typedef  unsigned long       DESBROWSEOPTION;
                                       /* match mode                  */
typedef  unsigned long       DESMATCHMODE;
                                       /* text handle                 */
typedef  unsigned long       DESHANDLE;
                                       /* browse window handle        */
typedef  unsigned long       DESWINDOWHANDLE;
                                       /* error message               */
typedef  char                DESMESSAGE[DES_MAX_MESSAGE_LENGTH + 1];
                                       /* browse session pointer      */
typedef  void *              DESBROWSESESSION;
                                       /* browse information pointer  */
typedef  void *              DESBROWSEINFO;
                                       /* match information pointer   */
typedef  char *              DESMATCHINFO;

/*--------------------------------------------------------------------*/
/*  Processing Conditions                                             */
/*--------------------------------------------------------------------*/
                                       /* search option(s)            */
#define  DES_RANK            0
#define  DES_MATCH           1
#define  DES_RANKANDMATCH    2
#define  DES_TEXTHANDLEONLY  3
                                       /* browse option(s)            */
#define  DES_BROWSE          0
#define  DES_NO_BROWSE       1
                                       /* get document text and hits  */
#define  DES_FAST            0         /* -- without dictionary       */
#define  DES_EXTENDED        1         /* -- use dictionary           */

#define  DES_NTS             SQL_NTS   /* null terminated string      */

/*--------------------------------------------------------------------*/
/*  API Services - calling conventions                                */
/*--------------------------------------------------------------------*/
#if defined(__UNIX__)
   #define  DESCALL
#elif defined(_WIN32)
   #define  DESCALL               __stdcall
#elif defined(_WINDOWS)
   #define  DESCALL               _export __far __pascal
#else
   #define  DESCALL               _System
#endif

/*--------------------------------------------------------------------*/
/*  API Services - prototype statements (Client Library)              */
/*--------------------------------------------------------------------*/
#ifdef  __cplusplus
extern "C"
{
#endif
                                       /* Search Function(s)          */
DESRETURN  DESCALL
DesGetSearchResultTable                /* Get Search Result Table     */
   (
   SQLHDBC            hdbc,            /* In -- CLI connection handle */
   char             * pTableSchema,    /* In -- schema of target table*/
                                       /* In -- length of schema name */
   DESSMALLINT        TableSchemaLength,
   char             * pTableName,      /* In -- name of target table  */
   DESSMALLINT        TableNameLength, /* In -- length of table name  */
   char             * pColumnName,     /* In -- name of target column */
   DESSMALLINT        ColumnNameLength,/* In -- length of column name */
   char             * pSearchArgument, /* In -- search argument       */
   DESSMALLINT        ArgumentLength,  /* In -- length of argument    */
   char             * pResultSchema,   /* In -- schema of result table*/
                                       /* In -- length of schema name */
   DESSMALLINT        ResultSchemaLength,
   char             * pResultTableName,/* In -- name of result table  */
   DESSMALLINT        ResultNameLength,/* In -- length of table name  */
   DESSEARCHOPTION    SearchOption,    /* In -- search option         */
   DESBROWSEOPTION    BrowseOption,    /* In -- browse option         */
   DESBROWSEINFO    * pBrowseInfo,     /* Out - browse information    */
   DESMESSAGE       * pErrorMessage    /* Out - error message         */
   );                                  /* function value: return code */

DESRETURN  DESCALL
DesCloseDocument
   (
   DESBROWSESESSION   BrowseSession,   /* In -- browse session handle */
   DESHANDLE          DocumentHandle   /* In -- document handle       */
   );                                  /* function value: return code */

DESRETURN  DESCALL
DesEndBrowseSession                    /* End Browse Session          */
   (
   DESBROWSESESSION   BrowseSession    /* In -- browse session handle */
   );                                  /* function value: return code */

DESRETURN  DESCALL                     /* Free Browse Information     */
DesFreeBrowseInfo
   (
   DESBROWSEINFO      BrowseInfo       /* In -- browse information    */
   );                                  /* function value: return code */

DESRETURN  DESCALL
DesGetBrowseInfo                       /* Get Browse Information      */
   (
   SQLHDBC            hdbc,            /* In -- CLI connection handle */
   SQLCHAR          * pHandle,         /* In -- text handle           */
   DESUSHORT          HandleLength,    /* In -- length of text handle */
   char             * pSearchArgument, /* In -- search argument       */
   DESSMALLINT        ArgumentLength,  /* In -- length of argument    */
   DESBROWSEINFO    * pBrowseInfo,     /* Out - browse information    */
   DESMESSAGE       * pErrorMessage    /* Out - error message         */
   );                                  /* function value: return code */

DESRETURN  DESCALL
DesGetMatches                          /* Get Document Text and Hits  */
   (
   DESBROWSESESSION   BrowseSession,   /* In -- browse session handle */
   DESHANDLE          DocumentHandle,  /* In -- document handle       */
                                       /*       for highlighting info */
   DESMATCHINFO     * pMatchInfo,      /* Out - match information     */
   DESULONG         * pMatchInfoLength,/* Out - length of match info  */
   DESMESSAGE       * pErrorMessage    /* Out - error message         */
   );                                  /* function value: return code */

DESRETURN  DESCALL
DesOpenDocument                        /* Open Document               */
   (
   DESBROWSESESSION   BrowseSession,   /* In -- browse session handle */
   SQLCHAR          * pHandle,         /* In -- text handle           */
   DESUSHORT          HandleLength,    /* In -- length of text handle */
   DESMATCHMODE       MatchMode,       /* In -- mode of creating      */
                                       /*       highlighting info     */
   DESHANDLE        * pDocumentHandle, /* Out - document handle       */
                                       /*       for highlighting info */
   DESMESSAGE       * pErrorMessage    /* Out - error message         */
   );                                  /* function value: return code */

DESRETURN  DESCALL
DesStartBrowseSession                  /* Start Browse Session        */
   (
   DESBROWSEINFO      BrowseInfo,      /* In -- browse information    */
   char             * pUserId,         /* In -- user identifier       */
   DESSMALLINT        UserIdLength,    /* In -- length of user id.    */
   char             * pPassword,       /* In -- password              */
   DESSMALLINT        PasswordLength,  /* In -- length of password    */
   DESBROWSESESSION * pBrowseSession,  /* Out - browse session handle */
   DESMESSAGE       * pErrorMessage    /* Out - error message         */
   );                                  /* function value: return code */

#ifdef  __cplusplus
}
#endif

#endif                                 /* end of DES_H_EXT            */

