
/**********************************************************************/
/*                                                                    */
/* (C) COPYRIGHT International Business Machines Corp. 1995,1996      */
/* All Rights Reserved                                                */
/* Licensed Materials - Property of IBM                               */
/*                                                                    */
/*  File Name: dessamp.c                                              */
/*                                                                    */
/*  Example for using the API and your OWN browser:                   */
/*                                                                    */
/*    Search for text in a text column, then browse a found           */
/*    document using the browse API                                   */
/*                                                                    */
/*  Prerequisites: The result table must have been created.           */
/*                 Use command file desrest in the samples            */
/*                 directory to create the result table DB2TX.RES_TBL.*/
/*                                                                    */
/**********************************************************************/

/*--------------------------------------------------------------------*/
/* Include statements                                                 */
/*--------------------------------------------------------------------*/
#include <ctype.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <des_ext.h>


/*--------------------------------------------------------------------*/
/* Function calls                                                     */
/*--------------------------------------------------------------------*/
int
get_text_handle
  (
   SQLHENV          henv,
   SQLHDBC          hdbc,
   DESSEARCHOPTION  SearchOption,
   char           * pResultTableSchema,
   DESSMALLINT      ResultSchemaLength,
   char           * pResultTableName,
   DESSMALLINT      ResultNameLength,
   SQLCHAR        * pHandle,
   DESSMALLINT    * pHandleLength
  );

int
initialize
  (
   SQLCHAR        * pDatabaseName,
   SQLCHAR        * pUserId,
   SQLCHAR        * pPassword,
   SQLHENV        * henv,
   SQLHDBC        * hdbc
  );

int
DesClearResultTable
  (
   SQLHDBC          hdbc,              /* In  CLI connection handle   */
   char           * pResultSchema,     /* In  schema of result table  */
                                       /* In  length of schema name   */
   DESSMALLINT      siResultSchemaLength,
   char           * pResultTableName,  /* In  name of result table    */
   DESSMALLINT      siResultNameLength /* In  length of result table  */
  );

void
printSqlErrMsg
  (
   SQLHENV          henv,
   SQLHDBC          hdbc,
   SQLHSTMT         hstmt
  );

int
terminateDB
  (
   SQLHENV          henv,
   SQLHDBC          hdbc
  );

/*====================================================================*/
/* Main function                                                      */
/*====================================================================*/
int
  main(int args,char *argv[])
{
   /*-----------------------------------------------------------------*/
   /* Declarations                                                    */
   /*-----------------------------------------------------------------*/
   DESRETURN        DESrc  = RC_SUCCESS;
   SQLRETURN        SQLrc  = RC_SUCCESS;
   SQLRETURN        WARNrc = RC_SUCCESS;
   DESRETURN        rc     = RC_SUCCESS;

   SQLHENV          henv   = SQL_NULL_HENV;
   SQLHDBC          hdbc   = SQL_NULL_HDBC;

   SQLCHAR          pDatabaseName[18 + 1] = "";
   SQLCHAR          pUserId[8 + 1]        = "";
   SQLCHAR          pPassword[18 + 1]     = "";

   DESMESSAGE       ErrorMessage;

   char             pTableSchema[8 + 1]       = "DB2TX";
   DESSMALLINT      TableSchemaLength         = DES_NTS;
   char             pTableName[18 + 1]        = "SAMPLE_L";
   DESSMALLINT      TableNameLength           = DES_NTS;
   char             pColumnName[18 + 1]       = "COMMENTHANDLE";
   DESSMALLINT      ColumnNameLength          = DES_NTS;
   char             pSearchArgument[1000]     = "\"compress\"";
   DESSMALLINT      ArgumentLength            = DES_NTS;
   char             pResultTableSchema[8 + 1] = "DB2TX";
   DESSMALLINT      ResultSchemaLength        = DES_NTS;
   char             pResultTableName[18 + 1]  = "RES_TBL";
   DESSMALLINT      ResultNameLength          = DES_NTS;
   DESSEARCHOPTION  SearchOption              = DES_MATCH;
   DESBROWSEOPTION  BrowseOption              = DES_BROWSE;
   DESMATCHMODE     MatchMode                 = DES_FAST;

   DESBROWSEINFO    BrowseInfo;
   DESBROWSESESSION BrowseSession;
   SQLCHAR          pHandle[256] = "";
   DESSMALLINT      HandleLength = 0;

   DESHANDLE        DocumentHandle;
   DESMATCHINFO     MatchInfo;
   DESULONG         MatchInfoLength;

   /*-----------------------------------------------------------------*/
   /* Program logic                                                   */
   /*-----------------------------------------------------------------*/

   /*-----------------------------------------------------------------*/
   /* Get input data for connection to the database                   */
   /*-----------------------------------------------------------------*/
   printf("\n------------------------------------------------------\n");
   printf("\n Text Extender API sample program                     \n");
   printf("\n------------------------------------------------------\n");

   printf("\nEnter the database name \n");
   scanf("%s",pDatabaseName);

   printf("\nEnter the user ID \n");
   scanf("%s",pUserId);

   printf("\nEnter the password\n");
   scanf("%s",pPassword);

   /*-----------------------------------------------------------------*/
   /* Initialize the database                                         */
   /*-----------------------------------------------------------------*/
   DESrc = initialize(pDatabaseName,pUserId,pPassword,&henv,&hdbc);

   if (DESrc != RC_SUCCESS)
     {
     printf(" initialize()    ..... %d \n",SQLrc);
     return(DESrc);
     }

   /*-----------------------------------------------------------------*/
   /* Delete all entries in result table                              */
   /*-----------------------------------------------------------------*/

   DESrc = DesClearResultTable
           (hdbc,
            pResultTableSchema,        /* in  schema of result table  */
            ResultSchemaLength,        /* in  length of schema name   */
            pResultTableName,          /* in  name of result table    */
            ResultNameLength           /* in  length of result table  */
           );
   /* No error handling necessary                                     */

   /*-----------------------------------------------------------------*/
   /* Call function DesGetSearchResultTable()                         */
   /*-----------------------------------------------------------------*/

   DESrc = DesGetSearchResultTable
           (hdbc,                      /* in  CLI connection handle   */
            pTableSchema,              /* in  schema of target table  */
            TableSchemaLength,         /* in  length of schema name   */
            pTableName,                /* in  name of target table    */
            TableNameLength,           /* in  length of table name    */
            pColumnName,               /* in  name of target column   */
            ColumnNameLength,          /* in  length of column name   */
            pSearchArgument,           /* in  search argument         */
            ArgumentLength,            /* in  search argument length  */
            pResultTableSchema,        /* in  schema of result table  */
            ResultSchemaLength,        /* in  length of schema name   */
            pResultTableName,          /* in  name of result table    */
            ResultNameLength,          /* in  length of result table  */
            SearchOption,              /* in  search option           */
            BrowseOption,              /* in  browse option           */
            &BrowseInfo,               /* out browsing information    */
            &ErrorMessage              /* out error message           */
           );

   printf(" DESGetSearchResultTable   DESrc :  %3d  \n", DESrc);
   if (DESrc != RC_SUCCESS)
   {  printf(" Error message: %s \n",ErrorMessage);
   }

   switch (DESrc)
   {
      case RC_SUCCESS:
            break;
      case RC_SE_DICTIONARY_NOT_FOUND:
            WARNrc = RC_SE_DICTIONARY_NOT_FOUND;
            break;
      case RC_SE_STOPWORD_IGNORED:
            WARNrc = RC_SE_STOPWORD_IGNORED;
            break;
      case RC_SE_CONFLICT_WITH_INDEX_TYPE:
            WARNrc = RC_SE_CONFLICT_WITH_INDEX_TYPE;
            break;
      case RC_SE_NO_DATA:
            terminateDB(henv,hdbc);
            return(DESrc);
      default:                         /* an error occurred           */
            /* printf(" Error message: %s\n",ErrorMessage);           */
            terminateDB(henv,hdbc);
            return(DESrc);
   }
   if (BrowseOption == DES_NO_BROWSE)
   {  DESrc = terminateDB(henv,hdbc);
      if (WARNrc != RC_SUCCESS)
      {  return(WARNrc);
      }
      return(DESrc);
   }

   /*-----------------------------------------------------------------*/
   /* Get a handle from the result table                              */
   /* For search option DES_RANK, get the one with the highest rank   */
   /*-----------------------------------------------------------------*/
   DESrc = get_text_handle(henv,hdbc,
                           SearchOption,
                           pResultTableSchema,ResultSchemaLength,
                           pResultTableName,ResultNameLength,
                           pHandle,&HandleLength
                          );
   printf ( " get_text_handle           DESrc :  %3d \n",DESrc);
   if (DESrc != RC_SUCCESS)
   {
      terminateDB(henv,hdbc);
      return(DESrc);
   }
   DESrc = terminateDB(henv,hdbc);

   /*-----------------------------------------------------------------*/
   /* Start a browse session                                          */
   /*-----------------------------------------------------------------*/
   DESrc = DesStartBrowseSession(BrowseInfo,
                                 (char*)pUserId,DES_NTS,
                                 (char*)pPassword,DES_NTS,
                                 &BrowseSession,
                                 &ErrorMessage
                                );
   printf (" DesStartBrowseSession     DESrc :  %3d \n",   DESrc);
   if (DESrc != RC_SUCCESS)
   {  printf(" Error message: %s\n",ErrorMessage);
      DesFreeBrowseInfo(BrowseInfo);
      return(DESrc);
   }

   /*-----------------------------------------------------------------*/
   /*  Open a document                                                */
   /*-----------------------------------------------------------------*/
   DESrc = DesOpenDocument(BrowseSession,
                           pHandle,
                           HandleLength,
                           MatchMode,
                           &DocumentHandle,
                           &ErrorMessage
                          );
   printf ( " DesOpenDocument           DESrc :  %3d \n", DESrc);
   if (DESrc != RC_SUCCESS)
   {  printf(" Error message: %s\n",ErrorMessage);
      if ((rc = DesEndBrowseSession(BrowseSession)) != RC_SUCCESS)
      {  printf(" DesEndBrowseSession() returned %d\n",rc);
      }
      DesFreeBrowseInfo(BrowseInfo);
      return(DESrc);
   }

   /*-----------------------------------------------------------------*/
   /* Get matches until the end of the document is reached            */
   /*-----------------------------------------------------------------*/
   do
   {  DESrc = DesGetMatches(BrowseSession,
                            DocumentHandle,
                            &MatchInfo,
                            &MatchInfoLength,
                            &ErrorMessage
                           );
      printf ( " DesGetMatches             DESrc :  %3d \n", DESrc);
      if (DESrc == RC_SUCCESS)
      {
      /* Include here the logic to parse the match information
       * and to prepare it as input to your browse function.
       */
      }

   }  while (DESrc == RC_SUCCESS);

   if (DESrc != RC_SE_END_OF_INFORMATION)
   {  printf(" Error message: %s\n",ErrorMessage);
      if ((rc = DesCloseDocument(BrowseSession,DocumentHandle))
          != RC_SUCCESS)
      {  printf(" DesCloseDocument() returned %d\n",rc);
      }
      if ((rc = DesEndBrowseSession(BrowseSession)) != RC_SUCCESS)
      {  printf(" DesEndBrowseSession() returned %d\n",rc);
      }
      DesFreeBrowseInfo(BrowseInfo);
      return(DESrc);
   }

   /*-----------------------------------------------------------------*/
   /* Close the document                                              */
   /*-----------------------------------------------------------------*/
   DESrc = DesCloseDocument(BrowseSession,
                            DocumentHandle
                           );
   printf (" DesCloseDocument          DESrc :  %3d \n", DESrc);
   if (DESrc != RC_SUCCESS)
   {  if ((rc = DesEndBrowseSession(BrowseSession)) != RC_SUCCESS)
      {  printf(" DesEndBrowseSession() returned %d\n",rc);
      }
      DesFreeBrowseInfo(BrowseInfo);
      return(DESrc);
   }

   /*-----------------------------------------------------------------*/
   /* End the browse session                                          */
   /*-----------------------------------------------------------------*/
   DESrc = DesEndBrowseSession(BrowseSession);
   printf (" DesEndBrowseSession       DESrc :  %3d \n", DESrc);
   if (DESrc != RC_SUCCESS)
   {  DesFreeBrowseInfo(BrowseInfo);
      return(DESrc);
   }

   DESrc = DesFreeBrowseInfo(BrowseInfo);
   printf (" DesFreeBrowseInfo         DESrc :  %3d \n", DESrc);
   if (DESrc != RC_SUCCESS)
   {  return(DESrc);
   }
   if (WARNrc != RC_SUCCESS)
   {  return(WARNrc);
   }
   return(DESrc);
}                                      /* end of function main()      */


/*====================================================================*/
/*                                                                    */
/* Get the text handle having highest rank or highest match           */
/* (if applicable) from the previous text search                      */
/*                                                                    */
/*====================================================================*/
int
  get_text_handle
  (
   SQLHENV          henv,              /* In -- environment handle    */
   SQLHDBC          hdbc,              /* In -- connection handle     */
   DESSEARCHOPTION  SearchOption,      /* In -- search option         */
   char             *pSchemaName,      /* In -- result table schema   */
   DESSMALLINT      SchemaNameLength,  /* In -- length of schema name */
   char             *pTableName,       /* In -- result table name     */
   DESSMALLINT      TableNameLength,   /* In -- length of table name  */
   SQLCHAR          *pHandle,          /* InOut pointer / text handle */
   DESSMALLINT      *pHandleLength     /* Out - length of text handle */
  )

{
   SQLRETURN        SQLrc = RC_SUCCESS;
   SQLHSTMT         hstmt = SQL_NULL_HSTMT;
   SQLINTEGER       docHdlLenTemp = 0;
   SQLINTEGER       lengthIn      = 0;
   SQLINTEGER       lengthOut     = 0;
   SQLDOUBLE        rank          = 0;

   char             t[18 + 1] = "";
   char             s[8 + 1]  = "";

   char  SqlStmtMsk[]   = " SELECT texthandle from \"%s\".\"%s\" ";
   char  SqlStmtMskMI[] = " SELECT texthandle,"
                                 " rank from \"%s\".\"%s\" order by 2";

   char  SqlStmt[sizeof(SqlStmtMskMI) + 8 + 18 + 1] = "";

   /*-----------------------------------------------------------------*/
   /* Build the SQl statement                                         */
   /*-----------------------------------------------------------------*/
   if (SchemaNameLength == DES_NTS)
   {  strcpy(s,pSchemaName);
   }
   else
   {  memset(s,'\0',sizeof(s));
      memcpy(s,pSchemaName,SchemaNameLength);
   }
   if (TableNameLength == DES_NTS)
   {  strcpy(t,pTableName);
   }
   else
   {  memset(t,'\0',sizeof(t));
      memcpy(t,pTableName,TableNameLength);
   }
   if ((SearchOption == DES_TEXTHANDLEONLY) ||
       (SearchOption == DES_MATCH))
   {  sprintf((char *)SqlStmt,(char *)SqlStmtMsk,s,t);
   }
   else
   {  sprintf((char *)SqlStmt,(char *)SqlStmtMskMI,s,t);
   }

   /*-----------------------------------------------------------------*/
   /* Allocate the statement and execute it                           */
   /*-----------------------------------------------------------------*/
   SQLrc = SQLAllocStmt(hdbc,&hstmt);
   if (SQLrc != RC_SUCCESS)
   {  printSqlErrMsg(henv,hdbc,SQL_NULL_HSTMT);
      return(SQLrc);
   }
   SQLrc = SQLExecDirect(hstmt,(SQLCHAR*)SqlStmt,SQL_NTS);
   if (SQLrc != RC_SUCCESS)
   {  printSqlErrMsg(henv,hdbc,hstmt);
      SQLFreeStmt(hstmt,SQL_DROP);
      return(SQLrc);
   }

   /*-----------------------------------------------------------------*/
   /* Bind the column                                                 */
   /*-----------------------------------------------------------------*/
   SQLrc = SQLBindCol(hstmt,1,SQL_C_BINARY,
                      (SQLPOINTER )pHandle,
                      DES_MAX_TEXT_HANDLE_LENGTH + 1,
                      &docHdlLenTemp
                     );
   if (SQLrc != RC_SUCCESS)
   {  printSqlErrMsg(henv,hdbc,hstmt);
      SQLFreeStmt(hstmt,SQL_DROP);
      return(SQLrc);
   }

   if ((SearchOption == DES_RANK) || (SearchOption == DES_RANKANDMATCH))
   {
      lengthIn = sizeof(double);
      SQLrc = SQLBindCol(hstmt,2,SQL_C_DOUBLE,&rank,
                         lengthIn,&lengthOut
                        );
      if (SQLrc != RC_SUCCESS)
      {  printSqlErrMsg(henv,hdbc,hstmt);
         SQLFreeStmt(hstmt,SQL_DROP);
         return(SQLrc);
      }
   }

   /*-----------------------------------------------------------------*/
   /* Fetch the first row (if available)                              */
   /*-----------------------------------------------------------------*/
   SQLrc = SQLFetch(hstmt);
   if (SQLrc != RC_SUCCESS)
   {  if (SQLrc != SQL_NO_DATA_FOUND)
      {  printSqlErrMsg(henv,hdbc,hstmt);
      }
      SQLFreeStmt(hstmt,SQL_DROP);
      return(SQLrc);
   }
   SQLrc = SQLFreeStmt(hstmt,SQL_DROP);
   if (SQLrc != RC_SUCCESS)
   {  printSqlErrMsg(henv,hdbc,hstmt);
      return(SQLrc);
   }

   *pHandleLength = (DESSMALLINT )docHdlLenTemp;
   return(RC_SUCCESS);

}                                      /* end of get_text_handle()    */


/*====================================================================*/
/*                                                                    */
/* Terminate the database                                             */
/*                                                                    */
/*====================================================================*/
int
  terminateDB
  (
   SQLHENV          henv,              /* In -- environment handle    */
   SQLHDBC          hdbc               /* In -- connection handle     */
  )

{
   SQLRETURN        SQLrc = SQL_SUCCESS;

   /*-----------------------------------------------------------------*/
   /* free all of database                                            */
   /*-----------------------------------------------------------------*/
   if ((SQLrc = SQLDisconnect(hdbc)) != SQL_SUCCESS)
   {  printSqlErrMsg(henv,hdbc,SQL_NULL_HSTMT);
   }
   if ((SQLrc = SQLFreeConnect(hdbc)) != SQL_SUCCESS)
   {  printSqlErrMsg(henv,hdbc,SQL_NULL_HSTMT);
   }
   if ((SQLrc = SQLFreeEnv(henv)) != SQL_SUCCESS)
   {  printSqlErrMsg(henv,SQL_NULL_HDBC,SQL_NULL_HSTMT);
   }
   return(SQLrc);
}                                      /* end of terminateDB()        */


/*====================================================================*/
/*                                                                    */
/* Initialize                                                         */
/*                                                                    */
/*====================================================================*/
int
  initialize
  (
   SQLCHAR          *pDatabaseName,    /* In -- database name (alias) */
   SQLCHAR          *pUserId,          /* In -- user identifier       */
   SQLCHAR          *pPassword,        /* In -- password              */
   SQLHENV          *phenv,            /* Out - environment handle    */
   SQLHDBC          *phdbc             /* Out - connection handle     */
  )

{
   SQLRETURN        SQLrc = RC_SUCCESS;

   SQLrc = SQLAllocEnv(phenv);
   if (SQLrc != SQL_SUCCESS)
   {  printf(" SQLAllocEnv()   ..... %d \n",SQLrc);
      return(SQLrc);
   }
   SQLrc = SQLAllocConnect(*phenv,phdbc);
   if (SQLrc == SQL_ERROR)
   {  printSqlErrMsg(*phenv,SQL_NULL_HDBC,SQL_NULL_HSTMT);
      terminateDB(*phenv,SQL_NULL_HDBC);
      return(SQLrc);
   }
   SQLrc = SQLConnect(*phdbc,
                      pDatabaseName,SQL_NTS,
                      pUserId,SQL_NTS,
                      pPassword,SQL_NTS
                     );
   if (SQLrc != SQL_SUCCESS)
   {  printSqlErrMsg(*phenv,*phdbc,SQL_NULL_HSTMT);
      terminateDB(*phenv,*phdbc);
      return(SQLrc);
   }
   return(SQLrc);

}                                      /* end of initialize()         */



/*====================================================================*/
/*                                                                    */
/* Print an SQL error message                                         */
/*                                                                    */
/*====================================================================*/
void
  printSqlErrMsg
  (
   SQLHENV          henv,              /* In -- environment handle    */
   SQLHDBC          hdbc,              /* In -- connection handle     */
   SQLHSTMT         hstmt              /* In -- statement handle      */
  )

{
   SQLCHAR          SqlState[6] = "";
   SQLINTEGER       NativeError = 0;
   SQLCHAR          ErrorMsg[SQL_MAX_MESSAGE_LENGTH + 1] = "";
   SQLSMALLINT      ErrorMsgLen = 0;

   SQLError(henv,hdbc,hstmt,
            SqlState,&NativeError,ErrorMsg,
            SQL_MAX_MESSAGE_LENGTH,&ErrorMsgLen
           );

   printf("\n An SQL error occurred\n");
   printf(" SQL state    : %s \n",SqlState);
   printf(" Native error : %d \n",NativeError);
   printf(" Error message: %s \n",ErrorMsg);

   return;

}                                      /* end of printSqlErrMsg()     */

/*====================================================================*/
/*                                                                    */
/* Delete result table entries                                        */
/*                                                                    */
/*====================================================================*/
int
  DesClearResultTable
  (
   SQLHDBC          hdbc,              /* In  CLI connection handle   */
   char            *pResultSchema,     /* In  schema of result table  */
                                       /* In  length of schema name   */
   DESSMALLINT     siResultSchemaLength,
   char            *pResultTableName,  /* In  name of result table    */
   DESSMALLINT     siResultNameLength  /* In  length of result table  */
  )
{

   SQLRETURN        SQLrc = RC_SUCCESS;
   SQLHSTMT         hstmt = SQL_NULL_HSTMT;
   char             t[18 + 1]      = "";
   char             s[8 + 1]       = "";
   char             SqlStmtMsk[]   = " DELETE FROM \"%s\".\"%s\" ";

   char             SqlStmt[sizeof(SqlStmtMsk) + 8 + 18 + 1] = "";

   /*-----------------------------------------------------------------*/
   /* Build the SQl statement                                         */
   /*-----------------------------------------------------------------*/
   if (siResultSchemaLength == DES_NTS)
   {  strcpy(s,pResultSchema);
   }
   else
   {  memset(s,'\0',sizeof(s));
      memcpy(s,pResultSchema,siResultSchemaLength);
   }

   if (siResultNameLength == DES_NTS)
   {  strcpy(t,pResultTableName);
   }
   else
   {  memset(t,'\0',sizeof(t));
      memcpy(t,pResultTableName,siResultNameLength);
   }

   sprintf((char *)SqlStmt,(char *)SqlStmtMsk,s,t);


   /*-----------------------------------------------------------------*/
   /* Allocate the statement and execute it                           */
   /*-----------------------------------------------------------------*/
   SQLrc = SQLAllocStmt(hdbc,&hstmt);
   if (SQLrc != RC_SUCCESS)
   {
      return(SQLrc);
   }

   SQLrc = SQLExecDirect(hstmt,(SQLCHAR*)SqlStmt,SQL_NTS);
   if (SQLrc != RC_SUCCESS)
   {
      SQLFreeStmt(hstmt,SQL_DROP);
      return(SQLrc);
   }

   return(RC_SUCCESS);

}                                      /* DesClearResultTable         */

/*====================================================================*/

