--**********************************************************************
--**********************************************************************
--**
--**  Product Name:      DB2 TextExtender        Owner: AM
--**
--**  Source File Name:  desctbl.ddl
--**
--**  Description:       The following script is executed
--**                     when a database is enabled for Text Extender.
--**
--**                     The program dessrvbg calls db2 to execute
--**                     this script by using the system command:
--**                     "export DB2DBDFT;
--**                      db2 -v -t -f /usr/lpp/db2tx_01_01_0000
--**                                    /misc/scripts/desctbl.ddl"
--**
--**                     As dessrvbg is owned by the Text Extender
--**                     Administrator and the s-Bit is set, the
--**                     TextExtender Administrator becomes the owner
--**                     of all the objects.
--**  STATUS: V1
--**
--**********************************************************************
--**********************************************************************

--*---------------------------------------------------------------------
--* Create Administration tables
--*---------------------------------------------------------------------
create table db2tx."TextColumns"
                  ("IndexName"         char(8) for bit data  not null,
                   "TextGroupName"     smallint              not null,
                   "StorageOption"     smallint,
                   "TextTableSchema"   char(8),
                   "TextTableName"     varchar(18),
                   "TextColumnName"    varchar(18),
                   "HandleColumnName"  varchar(18),
                   "HandleColumnIndex" varchar(18),
                   "LogTableName"      varchar(18),
                   "ColumnType"        smallint,
                   "Precision"         integer,
                   "FunctionSchema"    char(8),
                   "FunctionName"      varchar(18),
                   "SecurityFilter"    smallint,
                   "CCSID"             char(2) for bit data,
                   "Language"          char(2) for bit data,
                   "Format"            char(2) for bit data,
                   "PrototypeHandle"   varchar(60) for bit data,
                   "Version"           char(1),
                   "MapIdentifier"     integer               not null,
                   primary key ("IndexName","TextGroupName")
                  );

create table db2tx."TextIndices"
                  ("IndexName"         char(8) for bit data  not null,
                   "ServerName"        char(8) for bit data  not null,
                   "IndexCreation"     timestamp,
                   "LastBackup"        timestamp,
                   "LastScheduling"    timestamp,
                   "IndexMerge"        varchar(100),
                   "IndexType"         smallint,
                   "UpdateOnCreate"    smallint,
                   "IndexDirectory"    varchar(254)
                  );

create table db2tx."IndexUpdate"
                  ("IndexName"         char(8) for bit data  not null,
                   "Minimum"           integer               not null,
                   "Days"              varchar(15),
                   "Hours"             varchar(75),
                   "Minutes"           varchar(185),
                   primary key ("IndexName","Minimum")
                  );

create table db2tx."NodeGroups"
                  (
                   "NodeGroupName"     varchar(18)           not null,
                   "MapIdentifier"     integer               not null,
                   "PartitionMap"      long
                                       varchar for bit data,
                   "CreationTime"      timestamp,
                   primary key ("NodeGroupName","MapIdentifier")
                  );

create        index db2tx."TextColumnsIx1" on db2tx."TextColumns"
             ("TextTableSchema","TextTableName","TextColumnName"  ASC);

create        index db2tx."TextColumnsIx2" on db2tx."TextColumns"
             ("TextTableSchema","TextTableName","HandleColumnName"  ASC);

create        index db2tx."TextColumnsIx3" on db2tx."TextColumns"
             ("TextTableSchema","TextTableName","TextGroupName"  ASC);

create unique index db2tx."TextIndicesIx1" on db2tx."TextIndices"
             ("IndexName"  ASC, "ServerName"  ASC);
--           ("IndexName"  ASC);


--*---------------------------------------------------------------------
--* Grant privileges on Administration tables to public
--*---------------------------------------------------------------------
grant select on table db2tx."TextColumns" to public;
grant select on table db2tx."TextIndices" to public;
grant select on table db2tx."IndexUpdate" to public;
grant select on table db2tx."NodeGroups"  to public;


------------------------------------------------------------------------

