--****************************************************************************
--****************************************************************************
--**
--**  Product Name:      DB2 Text Extender
--**
--**  Source File Name:  descudf.ddl
--**
--**  Status:            Version 5.2.1
--**
--**  Function:          Declaration of all Text Extender User Defined Functions
--**
--**  Description:       The following script is executed
--**                     when a database is enabled for Text Extender.
--**
--**                     The program dessrvbg calls db2 to execute
--**                     this script by using the system command:
--**                     "export DB2DBDFT; db2 -v -t -f /opt/IBMdb2tx/V5.2
--**                      /misc/scripts/descudf.ddl"
--**
--**                     As dessrvbg is owned by the Text Extender
--**                     Administrator and the s-Bit is set, the
--**                     TextExtender Administrator becomes the owner
--**                     of all the objects.
--**
--**  Environment:       SUN-Solaris
--**
--**  Prerequisite:      All Text Extender User Defined Data Types must have
--**                     been declared previously. (See descudt.ddl).
--**
--**  Comments:
--**
--**          - !!! do not change 'specific' names !!!
--**
--**          - all DB2 TextExtender data types must be declared previously
--**
--**          - for drop statements see desdudf.ddl
--**
--**          - Note that the names of the TextExtender UDFs are not quoted.
--**            Thus, DB2 will set them to uppercase letters.
--**
--****************************************************************************
--****************************************************************************



--****************************************************************************
--****************************************************************************
--**
--**  Text search UDFs
--**
--**            - Search_Result(DB2TextH, LONG VARCHAR)
--**            - Search_Result(DB2TextFH,LONG VARCHAR)
--**
--**            - Contains     (DB2TextH, LONG VARCHAR)
--**            - Contains     (DB2TextFH,LONG VARCHAR)
--**
--**            - No_of_Matches(DB2TextH, LONG VARCHAR)
--**            - No_of_Matches(DB2TextFH,LONG VARCHAR)
--**
--**            - Rank         (DB2TextH, LONG VARCHAR)
--**            - Rank         (DB2TextFH,LONG VARCHAR)
--**
--**
--**    Comments:
--**            - common structure of all text search UDFs is
--**              udf_name     (<handle> ,<search argument>)
--**
--**
--****************************************************************************
--****************************************************************************

------------------------------------------------------------------------------
--
--      search_result( <text_handle>       , <search argument> )
--      search_result( <text_file__handle> , <search argument> )
--
--          Requires DB2 Version 5.2
--
--          Returns a table with the search result, if a document was found that
--          contains the search expression.
--
--          The UDF returns only the values requested in the select list.
--          It is important that the UDF gets the prototype handle from
--          the db2tx.textcolumns table for the table and handle column as input.
--
--          Example:
--
--            WITH rephandle (mydochandle) as
--              ( SELECT db2tx.db2texth(prototypehandle)
--                FROM db2tx.textcolumns
--                WHERE tableschema = 'DB2TX'  and
--                      tablename   = 'SAMPLE_L' and
--                      columnname  = 'COMMENT'
--              )
--            SELECT number_of_matches,rank,handle
--               FROM rephandle,
--               table(db2tx.search_result(mydochandle,'"DB2"')) T1 ;
--
--
--          The returned table has the following structure:
--
--            Column Name         Datatype
--
--            handle              db2tx.DB2TextH or db2tx.DB2TextFH
--            number_of_matches   INTEGER
--            rank                DOUBLE

------------------------------------------------------------------------------

create function db2tx.search_result
                (
                db2tx.DB2TextH,
                LONG VARCHAR
                )
       disallow parallel
       returns table
                (
                handle              db2tx.DB2TextH,
                number_of_matches   INTEGER,
                rank                DOUBLE
                )
        specific DES11M
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSearchResult'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        external action
        scratchpad
        final call
        dbinfo
        cardinality 1;

------------------------------------------------------------------------------

create function db2tx.search_result
                (
                db2tx.DB2TextFH,
                LONG VARCHAR
                )
       disallow parallel
       returns table
                (
                handle              db2tx.DB2TextFH,
                number_of_matches   INTEGER,
                rank                DOUBLE
                )
        specific DES11N
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSearchResult'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        external action
        scratchpad
        final call
        dbinfo
        cardinality 1;


------------------------------------------------------------------------------
--
--      Contains( <(file)handle> , <search argument> ) returns 1/0
--
--              Does a simple yes/no search.
--
--              Returns the INTEGER value 1 if a text document denoted by the
--              handle input parameter matches the search argument parameter.
--              Otherwise it returns 0.
--
------------------------------------------------------------------------------

create function db2tx.contains
        (
                db2tx.DB2TextH,
                LONG VARCHAR
        )
        returns INTEGER
        specific DES5A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSearch'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        external action
        scratchpad final call
        allow parallel;

------------------------------------------------------------------------------

create function db2tx.contains
        (
                db2tx.DB2TextFH,
                LONG VARCHAR
        )
        returns INTEGER
        specific DES5B
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSearch'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        external action
        scratchpad final call
        allow parallel;


------------------------------------------------------------------------------
--
--      No_of_Matches( <(file)handle>,<search argument>)
--                              returns <number of matches>
--
--              Returns an INTEGER value indicating how many times the
--              search term(s) matched terms in the text document denoted by
--              the handle input parameter.
--
------------------------------------------------------------------------------

create function db2tx.No_of_Matches
        (
                db2tx.DB2TextH,
                LONG VARCHAR
        )
        returns INTEGER
        specific DES5D
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSearch'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        external action
        scratchpad final call
        allow parallel;

------------------------------------------------------------------------------

create function db2tx.No_of_Matches
        (
                db2tx.DB2TextFH,
                LONG VARCHAR
        )
        returns INTEGER
        specific DES5E
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSearch'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        external action
        scratchpad final call
        allow parallel;


------------------------------------------------------------------------------
--
--      Rank( <(file)handle> , <search argument> ) returns <rank value>
--
--              Returns a FLOAT value between 0 and 1 indicating how well
--              the text document denoted by the handle parameter is
--              described by the search argument parameter.
--
------------------------------------------------------------------------------

create function db2tx.Rank
        (
                db2tx.DB2TextH,
                LONG VARCHAR
        )
        returns DOUBLE
        specific DES5G
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSearchRank'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        external action
        scratchpad final call
        allow parallel;

------------------------------------------------------------------------------

create function db2tx.Rank
        (
                db2tx.DB2TextFH,
                LONG VARCHAR
        )
        returns DOUBLE
        specific DES5H
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSearchRank'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        external action
        scratchpad final call
        allow parallel;



--****************************************************************************
--****************************************************************************
--**
--**  UDFs for accessing handle attributes
--**
--**            - CCSID(DB2TextH)
--**            - CCSID(DB2TextFH)
--**
--**            - Language(DB2TextH)
--**            - Language(DB2TextFH)
--**
--**            - Format(DB2TextH)
--**            - Format(DB2TextFH)
--**
--**            - File(DB2TextFH)
--**
--**  Comments:
--**            - the attribute value stored in the input handle is returned
--**              regardless whether it is a valid value or not
--**
--**            - common structure is     xxx( <handle> )
--**
--****************************************************************************
--****************************************************************************

------------------------------------------------------------------------------
--
--      CCSID( <(file)handle>) returns <ccsid>
--
--              Returns the CCSID from the handle input parameter.
--              This is the CCSID used for indexing the corresponding
--              text document.
--
------------------------------------------------------------------------------

create function db2tx.CCSID
        (
                db2tx.DB2TextH
        )
        returns INTEGER
        specific DES1A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESGetDocCCSID'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;

---------------------------------------------------------------------------

create function db2tx.CCSID
        (
                db2tx.DB2TextFH
        )
        returns INTEGER
        specific DES1B
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESGetDocCCSID'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      Language( <(file)handle> ) returns <language>
--
--              Returns the language information from the handle input
--              parameter.
--
------------------------------------------------------------------------------

create function db2tx.Language
        (
                db2tx.DB2TextH
        )
        returns VARCHAR(30)
        specific DES1E
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESGetDocLFF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;

---------------------------------------------------------------------------

create function db2tx.Language
        (
                db2tx.DB2TextFH
        )
        returns VARCHAR(30)
        specific DES1F
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESGetDocLFF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      Format( <(file)handle> ) returns <format>
--
--              Returns the format information from the handle input
--              parameter.
--
------------------------------------------------------------------------------

create function db2tx.Format
        (
                db2tx.DB2TextH
        )
        returns VARCHAR(30)
        specific DES1I
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESGetDocLFF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;

---------------------------------------------------------------------------

create function db2tx.Format
        (
                db2tx.DB2TextFH
        )
        returns VARCHAR(30)
        specific DES1J
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESGetDocLFF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      File( <file handle> ) returns <file name>
--
--              Returns the name of the corresponding file from the handle
--              input parameter.
--
------------------------------------------------------------------------------

create function db2tx.File
        (
                db2tx.DB2TextFH
        )
        returns VARCHAR(150)
        specific DES1M
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESGetDocLFF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;



--****************************************************************************
--**
--**  UDFs for setting handle attributes
--**
--**            - CCSID(DB2TextFH,INTEGER)
--**
--**            - Language(DB2TextH,VARCHAR(30))
--**            - Language(DB2TextFH,VARCHAR(30))
--**
--**            - Format(DB2TextH,VARCHAR(30))
--**            - Format(DB2TextFH,VARCHAR(30))
--**
--**            - File(DB2TextFH,VARCHAR(150)
--**
--*************************************************************************

------------------------------------------------------------------------------
--
--      CCSID( <file handle> , <ccsid> ) returns <file handle>
--
--              Changes the CCSID specification in the handle input parameter
--              and returns the changed handle.
--
------------------------------------------------------------------------------

create function db2tx.CCSID
        (
                db2tx.DB2TextFH,
                INTEGER
        )
        returns db2tx.DB2TextFH
        specific DES3A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSetDocCCSID'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      Language( <(file)handle> , <language> ) returns <(file)handle>
--
--              Changes the language specification in the handle input
--              parameter and returns the changed handle.
--
------------------------------------------------------------------------------

create function db2tx.Language
        (
                db2tx.DB2TextH,
                VARCHAR(30)
        )
        returns db2tx.DB2TextH
        specific DES3B
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSetDocLFF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;

---------------------------------------------------------------------------

create function db2tx.Language
        (
                db2tx.DB2TextFH,
                VARCHAR(30)
        )
        returns db2tx.DB2TextFH
        specific DES3C
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSetDocLFF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      Format( <(file)handle> , <format> ) returns <(file)handle>
--
--              Changes the format specification in the handle input parameter
--              and returns the changed handle.
--
------------------------------------------------------------------------------

create function db2tx.Format
        (
                db2tx.DB2TextH,
                VARCHAR(30)
        )
        returns db2tx.DB2TextH
        specific DES3D
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSetDocLFF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;

---------------------------------------------------------------------------

create function db2tx.Format
        (
                db2tx.DB2TextFH,
                VARCHAR(30)
        )
        returns db2tx.DB2TextFH
        specific DES3E
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSetDocLFF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      File( <file handle> , <file name> ) returns <file handle>
--
--              Changes the file specification in the handle input parameter
--              and returns the changed handle.
--
------------------------------------------------------------------------------

create function db2tx.File
        (
                db2tx.DB2TextFH,
                VARCHAR(150)
        )
        returns db2tx.DB2TextFH
        specific DES3F
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSetDocLFF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;



--****************************************************************************
--**
--**  UDFs for initializing and transforming handles
--**
--**    - Init_Text_Handle(VARCHAR(30),VARCHAR(30))
--**    - Init_Text_Handle(INTEGER,VARCHAR(30),VARCHAR(30),VARCHAR(150))
--**
--**    - Base_Handle(DB2TextH)
--**    - Base_Handle(DB2TextFH)
--**
--*************************************************************************

------------------------------------------------------------------------------
--
--      Init_Text_Handle(<format>,<language>) returns DB2TextH
--      Init_Text_Handle(<ccsid>,<format>,<language>,<file>) returns DB2TextFH
--
--              Returns a partially initialized handle ((ccsid and) format and
--              language (and file)) that is intended to be inserted into a
--              handle column.
--
------------------------------------------------------------------------------

create function db2tx.Init_Text_Handle
        (
                VARCHAR(30),
                VARCHAR(30)
        )
        returns db2tx.DB2TextH
        specific DES2A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESInitTextHandle'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;

---------------------------------------------------------------------------

create function db2tx.Init_Text_Handle
        (
                INTEGER,
                VARCHAR(30),
                VARCHAR(30),
                VARCHAR(150)
        )
        returns db2tx.DB2TextFH
        specific DES2B
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESInitTextFileHandle'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      Base_Handle( <(file) handle>) returns <handle>
--
--              Returns the handle that contains information that is
--              common to all handle types (i.e. it cuts all type specific
--              information like file name).
--              A handle of type DB2TextH is returned.
--
--              This function is intended to be used in UNION queries
--              where handles of different types are involved in.
--
------------------------------------------------------------------------------

create function db2tx.Base_Handle
        (
                db2tx.DB2TextH
        )
        returns db2tx.DB2TextH
        specific DES4C
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESTransformHandle'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;

------------------------------------------------------------------------------

create function db2tx.Base_Handle
        (
                db2tx.DB2TextFH
        )
        returns db2tx.DB2TextH
        specific DES4D
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESTransformHandle'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;



--****************************************************************************
--**
--**  UDFs dealing with lists of handles of type DB2TextH and DB2TextFH,
--**
--**    !!! They are provided to improve performance for queries  !!!
--**    !!! where very selective search arguments run against     !!!
--**    !!! very large tables.                                    !!!
--**    !!! They are intended to be used by SQL experts only.     !!!
--**
--**            - Handle_List(DB2TextH,LONG VARCHAR)
--**            - Handle_List(DB2TextFH,LONG VARCHAR)
--**
--**            - No_of_Documents(DB2TextHListP)
--**            - No_of_Documents(DB2TextFHListP)
--**
--**            - Handle(DB2TextHListP,INTEGER)
--**            - Handle(DB2TextFHListP,INTEGER)
--**
--**            - Rank(DB2TextHListP,INTEGER)
--**            - Rank(DB2TextFHListP,INTEGER)
--**
--**            - No_of_Matches(DB2TextHListP,INTEGER)
--**            - No_of_Matches(DB2TextFHListP,INTEGER)
--**
--*************************************************************************

------------------------------------------------------------------------------
--
--      Handle_List( <(file)handle>, <search argument> )
--                                      returns <(file)handle list>
--
--              It receives a handle h and a search argument and
--              returns a 'pointer' to a list containing handles.
--              The list contains an entry for each document that corresponds
--              to a handle that is stored in h's base table column and that
--              matches the search argument. (To be more precise:
--              the list contains an entry for each document of
--              h's index and group that matches the search argument.)
--
--              The 'pointer' to this list is only accessible within the scope
--              of the SQL statement invoking this function. (Currently, the
--              'pointer' is an ID of a shared memory segment that is freed at
--              the end of the statement.)
--
--              The function is intended to be called once per statement, i.e.
--              for a single handle value (and not a column containing many
--              handles) respectively for an intermediate result set of size 1.
--
------------------------------------------------------------------------------

create function db2tx.Handle_List
        (
                db2tx.DB2TextH,
                LONG VARCHAR
        )
        returns db2tx.DB2TextHListP
        specific DES5J
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSearchList'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        external action
        scratchpad final call
        disallow parallel;

------------------------------------------------------------------------------

create function db2tx.Handle_List
        (
                db2tx.DB2TextFH,
                LONG VARCHAR
        )
        returns db2tx.DB2TextFHListP
        specific DES5K
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESSearchList'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        external action
        scratchpad final call
        disallow parallel;


------------------------------------------------------------------------------
--
--      No_of_Documents( <(file)handle list> )
--                                      returns <length of list>
--
--              It receives a (file) handle list and returns its length,
--              i.e. the number of handles stored in the list.
--
------------------------------------------------------------------------------

create function db2tx.No_of_Documents
        (
                db2tx.DB2TextHListP
        )
        returns INTEGER
        specific DES7A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESListLength'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        disallow parallel;

------------------------------------------------------------------------------

create function db2tx.No_of_Documents
        (
                db2tx.DB2TextFHListP
        )
        returns INTEGER
        specific DES7B
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESListLength'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        disallow parallel;


------------------------------------------------------------------------------
--
--      Handle( <(file)handle list> , <i'th element>)
--                                      returns <(file)handle>
--
--              It receives a (file) handle list and an INTEGER value i and
--              returns a (file) handle for the i'th element of the list.
--
------------------------------------------------------------------------------

create function db2tx.Handle
        (
                db2tx.DB2TextHListP,
                INTEGER
        )
        returns db2tx.DB2TextH
        specific DES7D
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESListElement'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        disallow parallel;

------------------------------------------------------------------------------

create function db2tx.Handle
        (
                db2tx.DB2TextFHListP,
                INTEGER
        )
        returns db2tx.DB2TextFH
        specific DES7E
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESListElement'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        disallow parallel;


------------------------------------------------------------------------------
--
--      Rank( <(file)handle list> , <i'th element>) returns <rank value>
--
--              It receives a (file) handle list and an INTEGER value i and
--              returns an INTEGER value between 0 and 100 indicating how well
--              the i'th element of the list is described by the search
--              argument that was used for creating the (file) handle list.
--
------------------------------------------------------------------------------

create function db2tx.Rank
        (
                db2tx.DB2TextHListP,
                INTEGER
        )
        returns DOUBLE
        specific DES7G
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESListElementRank'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        disallow parallel;

------------------------------------------------------------------------------

create function db2tx.Rank
        (
                db2tx.DB2TextFHListP,
                INTEGER
        )
        returns DOUBLE
        specific DES7H
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESListElementRank'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        disallow parallel;


------------------------------------------------------------------------------
--
--      No_of_Matches( <(file)handle list> , <i'th element>)
--                                      returns <number of matches>
--
--              It receives a (file) handle list and an INTEGER value i and
--              returns an INTEGER value indicating how many times the i'th
--              element of the list is matched by the search
--              argument that was used for creating the (file) handle list.
--
------------------------------------------------------------------------------

create function db2tx.No_of_Matches
        (
                db2tx.DB2TextHListP,
                INTEGER
        )
        returns INTEGER
        specific DES7J
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESListElementMatches'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        disallow parallel;

------------------------------------------------------------------------------

create function db2tx.No_of_Matches
        (
                db2tx.DB2TextFHListP,
                INTEGER
        )
        returns INTEGER
        specific DES7K
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESListElementMatches'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        disallow parallel;



--****************************************************************************
--**
--**  Miscellaneous
--**
--**            - Refine(LONG VARCHAR,LONG VARCHAR)
--**
--*************************************************************************

------------------------------------------------------------------------------
--
--      Refine(<search argument 1>, <search argument 2>)
--                                      returns <search argument 3>
--
--              It receives a search argument and a second search argument
--              used for refinement of the first one.
--              The string
--                      (<search argument 1>) and (<search argument 2>)
--              is returned.
--
------------------------------------------------------------------------------

create function db2tx.Refine
        (
                LONG VARCHAR,
                LONG VARCHAR
        )
        returns LONG VARCHAR
        specific DESRefine
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESRefine'
        language C
        parameter style db2sql
        not variant
        not fenced
        null call
        no sql
        no external action
        disallow parallel;



--****************************************************************************
--****************************************************************************
--**
--**
--**    THE FOLLOWING UDFS ARE FOR INTERNAL TEXT EXTENDER USE ONLY
--**
--**
--****************************************************************************
--****************************************************************************

------------------------------------------------------------------------------
--
--      DesUpdateTextH(
--              <handle>,               either NULL or a handle created by
--                                      the UDF Init_TextH
--              <trigger version>,      version of trigger
--              <server name>,          name of SM server
--              <index name>,           name of SM index
--              <group name>,           name of SM index group
--              <db ccsid>,             CCSID of database
--              <doc ccsid>,            CCSID of document
--              <doc language>,         language of document
--              <doc format>            format of document
--                      )
--                              returns <handle>
--
--              Creates a handle of type TextH.
--
--              This internal function presumes that all input variables
--              but <handle> or not NULL. It is intended that this function
--              is called from Text Extender triggers only.
--
--              Input parameter are not checked for validity except
--                      - the trigger version
--                      - the length, version and type of the input handle
--                        (if not NULL)
--
------------------------------------------------------------------------------

create function db2tx.DesUpdateTextH
        (
                db2tx.DB2TextH,
                CHAR (1) FOR BIT DATA,
                CHAR (8) FOR BIT DATA,
                CHAR (8) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                CHAR (2) FOR BIT DATA
        )
        returns db2tx.DB2TextH
        specific DesUpdateTextH
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESupdateTextHandle'
        language C
        parameter style db2sql
        variant
        not fenced
        null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      DesUpdateTextFileH(
--              <file handle>,          either NULL or a handle created by
--                                      the UDF Init_TextFileH
--              <trigger version>,      version of trigger
--              <server name>,          name of SM server
--              <index name>,           name of SM index
--              <group name>,           name of SM index group
--              <db ccsid>,             CCSID of database
--              <doc ccsid>,            CCSID of document
--              <doc language>,         language of document
--              <doc format>,           format of document
--              <file name>             name of the document's file
--                      )
--                              returns <file handle>
--
--              Creates a handle of type TextFileH.
--
--              This internal function presumes that all input variables
--              but <handle> or not NULL. It is intended that this function
--              is called from Text Extender triggers only.
--
--              Input parameter are not checked for validity except
--                      - the trigger version
--                      - the length, version and type of the input handle
--                        (if not NULL)
--                      - the accessibility of the file (warning only)
--
------------------------------------------------------------------------------

create function db2tx.DesUpdateTextFileH
        (
                db2tx.DB2TextFH,
                CHAR (1) FOR BIT DATA,
                CHAR (8) FOR BIT DATA,
                CHAR (8) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                VARCHAR (150)
        )
        returns db2tx.DB2TextFH
        specific DesUpdateTextFileH
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESupdateTextFileHandle'
        language C
        parameter style db2sql
        variant
        not fenced
        null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      DesUpdateTextPartH(
--              <part handle>,          either NULL or a handle created by
--                                      the UDF Init_TextPartH
--              <ref handle>,           either NULL or a reference handle
--                                      if != NULL the ID will be reused
--                                      for the output handle
--              <trigger version>,      version of trigger
--              <server name>,          name of SM server
--              <index name>,           name of SM index
--              <group name>,           name of SM index group
--              <db ccsid>,             CCSID of database
--              <doc ccsid>,            CCSID of document
--              <doc language>,         language of document
--              <doc format>,           format of document
--              <file name>,            name of the document's file
--              <security filter>       security filter
--                      )
--                              returns <file handle>
--
--              Creates a handle of type TextPartH.
--
--              This internal function presumes that all input variables
--              but <handle> and <ref handle> or not NULL.
--              It is intended that this function
--              is called from Text Extender triggers only.
--
--              Input parameter are not checked for validity except
--                      - the trigger version
--                      - the length, version and type of the input handle
--                        (if not NULL)
--                      - the accessibility of the file (warning only)
--
------------------------------------------------------------------------------

create function db2tx.DesUpdateTextPartH
        (
                db2tx.DB2TextPH,
                db2tx.DB2TextPH,
                CHAR (1) FOR BIT DATA,
                CHAR (8) FOR BIT DATA,
                CHAR (8) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                CHAR (2) FOR BIT DATA,
                SMALLINT
        )
        returns db2tx.DB2TextPH
        specific DesUpdateTextPartH
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESupdateTextPartHandle'
        language C
        parameter style db2sql
        variant
        not fenced
        null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      DesGetIndexType(
--              <index type number>
--                     )
--                     returns <index type string>
--
--              Receives the internal representation of an index type
--              and returns a string that can be interpreted by end users
--
--              This function is for use in the definition of the
--              Text Extender administration view
--
------------------------------------------------------------------------------

create function db2tx.DesGetIndexType
        (
                SMALLINT
        )
        returns VARCHAR(30)
        specific DES8A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESPrintAdminInfoSmall'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      DesGetUpdOnCreate(
--              <update flag number>
--                       )
--                       returns <update flag string>
--
--              Receives the internal representation of the update flag
--              (i.e. whether an index will be updated automatically after
--               enabling a table).
--              It returns a string that can be interpreted by end users
--
--              This function is for use in the definition of the
--              Text Extender administration view
--
------------------------------------------------------------------------------

create function db2tx.DesGetUpdOnCreate
        (
                SMALLINT
        )
        returns VARCHAR(30)
        specific DES8B
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESPrintAdminInfoSmall'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      DesGetIndexOption(
--              <index type number>
--                       )
--                       returns <index type string>
--
--              Receives the internal representation of an index type
--              and returns a string that can be interpreted by end users
--
--              This function is for use in the definition of the
--              Text Extender administration view
--
------------------------------------------------------------------------------

create function db2tx.DesGetIndexOption
        (
                SMALLINT
        )
        returns VARCHAR(30)
        specific DES8C
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESPrintAdminInfoSmall'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      DesGetDefDocLang(
--              <language (internal form)>
--                      )
--                              returns <language name>
--
--              Receives the internal representation of the document
--              language and returns the corresponding name.
--
--              This function is for use in the definition of the
--              Text Extender administration view
--
------------------------------------------------------------------------------

create function db2tx.DesGetDefDocLang
        (
                CHAR(2) FOR BIT DATA
        )
        returns VARCHAR(30)
        specific DES9A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESPrintDefaultDocLF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      DesGetDefDocFormat(
--              <language (internal form)>
--                      )
--                              returns <format name>
--
--              Receives the internal representation of the document
--              format and returns the corresponding name.
--
--              This function is for use in the definition of the
--              Text Extender administration view
--
------------------------------------------------------------------------------

create function db2tx.DesGetDefDocFormat
        (
                CHAR(2) FOR BIT DATA
        )
        returns VARCHAR(30)
        specific DES9B
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESPrintDefaultDocLF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      DesGetDefDocCCSID(
--              <ccsid (internal form)>
--                      )
--                              returns <ccsid (external value)>
--
--              Receives the internal representation of the document
--              ccsid and returns the corresponding name.
--
--              This function is for use in the definition of the
--              Text Extender administration view
--
------------------------------------------------------------------------------

create function db2tx.DesGetDefDocCCSID
        (
                CHAR(2) FOR BIT DATA
        )
        returns SMALLINT
        specific DES10A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESPrintDefaultDocCCSID'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      DesGetNodeNumber(
--              <server name>
--                      )
--                              returns <node number>
--
--              Receives a search (service) server name
--              and returns the corresponding node number.
--
--              This function is for use in the definition of the
--              Text Extender administration view
--
------------------------------------------------------------------------------

create function db2tx.DesGetNodeNumber
        (
                CHAR(8) FOR BIT DATA
        )
        returns INTEGER
        specific DES11A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESGetNodeNumber'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      DesGetServerName(
--              <node number>
--                      )
--                              returns <server name>
--
--              Receives a node number
--              and returns the corresponding search (service) server name.
--
--              This function is for use in the definition of the
--              Text Extender administration view
--
------------------------------------------------------------------------------

create function db2tx.DesGetServerName
        (
                INTEGER
        )
        returns VARCHAR(30)
        specific DES12A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESGetServerName'
        language C
        parameter style db2sql
        not variant
        fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      DesGetPartKeyValue(
--              <node number>
--                        )
--                              returns <partitioning key>
--
--              Receives a node number
--              and returns a corresponding partitioning key.
--
--              This function is for use in the definition of the
--              Text Extender administration view
--
------------------------------------------------------------------------------

create function db2tx.DesGetPartKeyValue
        (
                INTEGER
        )
        returns INTEGER
        specific DES13A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESGetPartKeyValue'
        language C
        parameter style db2sql
        not variant
        fenced
        not null call
        no sql
        no external action
        allow parallel;


------------------------------------------------------------------------------
--
--      DesGetPK(
--              <node number>
--              )
--                              returns <partitioning key>
--
--              Receives a node number
--              and returns a corresponding partitioning key.
--
--              This function is for use in the definition of the
--              Text Extender administration view
--
------------------------------------------------------------------------------

create function db2tx.DesGetPK
        (
                INTEGER
        )
        returns INTEGER
        specific DES14A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESGetPK'
        language C
        parameter style db2sql
        not variant
        fenced
        not null call
        no sql
        no external action
        allow parallel
        dbinfo;

------------------------------------------------------------------------------
--
--      DesCompareMap(
--              partition map1,
--              partitoin map2)
--                              returns 1=same / 0=different
--
--              Receives a node number
--              and returns a corresponding partitioning key.
--
--              This function is for use in the definition of the
--              Text Extender administration view
--
------------------------------------------------------------------------------

create function db2tx.DesCompareMap
        (
                LONG VARCHAR FOR BIT DATA,
                LONG VARCHAR FOR BIT DATA
        )
        returns INTEGER
        specific DES15A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesui.a!DESCompareMap'
        language C
        parameter style db2sql
        not variant
        fenced
        not null call
        no sql
        no external action
        allow parallel
        dbinfo;


------------------------------------------------------------------------------
--
--      DesTraceUDF(
--              integer start,
--              )
--                              returns 1=same / 0=different
--
--              Use ives a node number
--              and returns a corresponding partitioning key.
--
--              This function is for use in the definition of the
--              Text Extender administration view
--
------------------------------------------------------------------------------

create function db2tx.DesTraceUDF
        (
                INTEGER
        )
        returns INTEGER
        specific DES16A
        external name '/opt/IBMdb2tx/V5.2/lib/libdesue.a!DESTraceUDF'
        language C
        parameter style db2sql
        not variant
        not fenced
        not null call
        no sql
        no external action
        allow parallel
        dbinfo;
