
--**********************************************************************
--**********************************************************************
--**
--**  Product Name:      DB2 TextExtender        Owner: AM
--**
--**  Source File Name:  descview.ddl
--**
--**  Description:     The following script is executed
--**                   when a database is enabled for Text Extender.
--**
--**                   The program dessrvbg calls db2 to execute
--**                   this script by using the system command:
--**                   "export DB2DBDFT; db2 -v -t -f <TX_install_path>
--**                    /misc/scripts/descview.ddl"
--**
--**                   As dessrvbg is owned by the Text Extender
--**                   Administrator and the s-Bit is set, the
--**                   TextExtender Administrator becomes the owner
--**                   of all the objects.
--**  STATUS: V1
--**
--**********************************************************************
--**********************************************************************

--*---------------------------------------------------------------------
--* Create Administration View
--*---------------------------------------------------------------------
create view db2tx.textcolumns
       ( tableschema, tablename, columnname, handlename,
         indexname,
         ccsid, language, format,
         prototypehandle
       )
   as  select  "TextTableSchema",
               "TextTableName",
               "TextColumnName",
               "HandleColumnName",
               substr("LogTableName",4,8),
               db2tx.DesGetDefDocCCSID("CCSID"),
               db2tx.DesGetDefDocLang("Language"),
               db2tx.DesGetDefDocFormat("Format"),
               "PrototypeHandle"
       from  db2tx."TextColumns";

------------------------------------------------------------------------

create view db2tx.textindexes
       ( tableschema, tablename, columnname, handlename,
         indexname, logtable, indextype,
         minimum, days, hours, minutes,
         indexdirectory, updateoncreate, commonindex,
         ccsid, language, format,
         functionschema, functionname,
         prototypehandle,
         indexoption,
         nodenumber
       )
   as
     with colindex as (  select
                                case ( select min(d."TextGroupName")
                                from  db2tx."TextColumns" as d
                                where a."TextTableSchema"=d."TextTableSchema" and
                                      a."TextTableName" = d."TextTableName"
                                     )
                                 when 0 then 'YES'
                                 else 'NO' end as commonindex,
                                a."TextTableSchema",
                                a."TextTableName",
                                a."TextColumnName",
                                a."HandleColumnName",
                                a."LogTableName",
                                a."CCSID",
                                a."Language",
                                a."Format",
                                a."FunctionSchema",
                                a."FunctionName",
                                a."PrototypeHandle",
                                b."IndexType",
                                b."IndexDirectory",
                                b."UpdateOnCreate",
                                b."ServerName",
                                a."IndexName"
                             from
                                db2tx."TextColumns" a,
                                db2tx."TextIndices" b
                             where
                                a."IndexName" = b."IndexName" ),
        colupdate as (
                         select a.*,
                                c."Minimum",
                                c."Days",
                                c."Hours",
                                c."Minutes"
                             from
                                colindex            a,
                                db2tx."IndexUpdate" c
                              where
                                a."IndexName" = c."IndexName" ),
          diff as (
                       select *  from  colindex
                       except all
                       select  commonindex,
                               "TextTableSchema",
                               "TextTableName",
                               "TextColumnName",
                               "HandleColumnName",
       	                       "LogTableName",
                               "CCSID",
                               "Language",
                               "Format",
                               "FunctionSchema",
                               "FunctionName",
                               "PrototypeHandle",
                               "IndexType",
                               "IndexDirectory",
                               "UpdateOnCreate",
                               "ServerName",
                               "IndexName"
                             from
                                colupdate )
        select  "TextTableSchema",
                "TextTableName",
                "TextColumnName",
              	"HandleColumnName",
                substr("LogTableName",4,8),
                "LogTableName",
                db2tx.DesGetIndexType("IndexType"),
                "Minimum",
                "Days",
                "Hours",
                "Minutes",
                "IndexDirectory",
                db2tx.DesGetUpdOnCreate("UpdateOnCreate"),
                commonindex,
                db2tx.DesGetDefDocCCSID("CCSID"),
                db2tx.DesGetDefDocLang("Language"),
                db2tx.DesGetDefDocFormat("Format"),
                "FunctionSchema",
                "FunctionName",
                "PrototypeHandle",
                db2tx.DesGetIndexOption("IndexType"),
                db2tx.DesGetNodeNumber("ServerName")
       from colupdate
       union all
       select   "TextTableSchema",
                "TextTableName",
                "TextColumnName",
                "HandleColumnName",
                substr("LogTableName",4,8),
                "LogTableName",
                db2tx.DesGetIndexType("IndexType"),
                cast(null as integer) as "Minimum",
                cast(null as varchar(15)) as "Days",
                cast(null as varchar(75)) as "Hours",
                cast(null as varchar(185)) as "Minutes",
                "IndexDirectory",
                db2tx.DesGetUpdOnCreate("UpdateOnCreate"),
                commonindex,
                db2tx.DesGetDefDocCCSID("CCSID"),
                db2tx.DesGetDefDocLang("Language"),
                db2tx.DesGetDefDocFormat("Format"),
                "FunctionSchema",
                "FunctionName",
                "PrototypeHandle",
                db2tx.DesGetIndexOption("IndexType"),
                db2tx.DesGetNodeNumber("ServerName")
       from diff;

--*---------------------------------------------------------------------
--* Grant privileges on Administration View to public
--*---------------------------------------------------------------------
grant select on table  db2tx.textcolumns to public;
grant select on table  db2tx.textindexes to public;

------------------------------------------------------------------------

